Class: Google::Apis::CloudtasksV2beta2::BatchCreateTasksRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb

Overview

Request message for [BatchCreateTasks].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchCreateTasksRequest

Returns a new instance of BatchCreateTasksRequest.



349
350
351
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

Optional. This field will be used to identify the long running operation, avoiding duplication when user retries. If not provided, then a UUID will be generated at server side. Corresponds to the JSON property requestId

Returns:

  • (String)


338
339
340
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 338

def request_id
  @request_id
end

#requestsArray<Google::Apis::CloudtasksV2beta2::CreateTaskRequest>

Required. The list of requests to create tasks. The queue specified in parent field of each CreateTaskRequest will be the same. This validation happens on the client side as well as in the handler. BatchCreateTasksRequest.parent will also be the same value as the individual CreateTaskRequest.parent . The maximum number of requests is 100. Corresponds to the JSON property requests



347
348
349
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 347

def requests
  @requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



354
355
356
357
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 354

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
  @requests = args[:requests] if args.key?(:requests)
end