Class: Google::Apis::CloudtasksV2beta2::CloudTasksService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudtasksV2beta2::CloudTasksService
- Defined in:
- lib/google/apis/cloudtasks_v2beta2/service.rb
Overview
Cloud Tasks API
Manages the execution of large numbers of distributed requests.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudtasks.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#acknowledge_task(name, acknowledge_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Empty
Acknowledges a pull task.
-
#buffer_task(queue, task_id, buffer_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::BufferTaskResponse
Creates and buffers a new task without the need to explicitly define a Task message.
-
#cancel_task_lease(name, cancel_lease_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Cancel a pull task's lease.
-
#create_project_location_queue(parent, queue_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Creates a queue.
-
#create_task(parent, create_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Creates a task and adds it to a queue.
-
#delete_project_location_queue(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Empty
Deletes a queue.
-
#delete_project_location_queue_task(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Empty
Deletes a task.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Location
Gets information about a location.
-
#get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::CmekConfig
Gets the CMEK config.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_queue(name, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Gets a queue.
-
#get_project_location_queue_task(name, response_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Gets a task.
-
#get_queue_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Policy
Gets the access control policy for a Queue.
-
#initialize ⇒ CloudTasksService
constructor
A new instance of CloudTasksService.
-
#lease_tasks(parent, lease_tasks_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::LeaseTasksResponse
Leases tasks from a pull queue for lease_duration.
-
#list_project_location_queue_tasks(parent, page_size: nil, page_token: nil, response_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::ListTasksResponse
Lists the tasks in a queue.
-
#list_project_location_queues(parent, filter: nil, page_size: nil, page_token: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::ListQueuesResponse
Lists queues.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_queue(name, queue_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Updates a queue.
-
#pause_queue(name, pause_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Pauses the queue.
-
#purge_queue(name, purge_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Purges a queue by deleting all of its tasks.
-
#renew_task_lease(name, renew_lease_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Renew the current lease of a pull task.
-
#resume_queue(name, resume_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Resume a queue.
-
#run_task(name, run_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Forces a task to run now.
-
#set_queue_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Policy
Sets the access control policy for a Queue.
-
#test_queue_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::TestIamPermissionsResponse
Returns permissions that a caller has on a Queue.
-
#update_api_queue(http_body_object = nil, app_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Empty
Update queue list by uploading a queue.yaml file.
-
#update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::CmekConfig
Creates or Updates a CMEK config.
Constructor Details
#initialize ⇒ CloudTasksService
Returns a new instance of CloudTasksService.
47 48 49 50 51 52 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudtasks_v2beta2', client_version: Google::Apis::CloudtasksV2beta2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#acknowledge_task(name, acknowledge_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Empty
Acknowledges a pull task. The worker, that is, the entity that leased this task must call this method to indicate that the work associated with the task has finished. The worker must acknowledge a task within the lease_duration or the lease will expire and the task will become available to be leased again. After the task is acknowledged, it will not be returned by a later LeaseTasks, GetTask, or ListTasks.
770 771 772 773 774 775 776 777 778 779 780 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 770 def acknowledge_task(name, acknowledge_task_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+name}:acknowledge', ) command.request_representation = Google::Apis::CloudtasksV2beta2::AcknowledgeTaskRequest::Representation command.request_object = acknowledge_task_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Empty::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#buffer_task(queue, task_id, buffer_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::BufferTaskResponse
Creates and buffers a new task without the need to explicitly define a Task message. The queue must have HTTP target. To create the task with a custom ID, use the following format and set TASK_ID to your desired ID: projects/ PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID/tasks/TASK_ID:buffer To create the task with an automatically generated ID, use the following format: projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID/tasks:buffer.
812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 812 def buffer_task(queue, task_id, buffer_task_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+queue}/tasks/{taskId}:buffer', ) command.request_representation = Google::Apis::CloudtasksV2beta2::BufferTaskRequest::Representation command.request_object = buffer_task_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::BufferTaskResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta2::BufferTaskResponse command.params['queue'] = queue unless queue.nil? command.params['taskId'] = task_id unless task_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_task_lease(name, cancel_lease_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Cancel a pull task's lease. The worker can use this method to cancel a task's lease by setting its schedule_time to now. This will make the task available to be leased to the next caller of LeaseTasks.
849 850 851 852 853 854 855 856 857 858 859 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 849 def cancel_task_lease(name, cancel_lease_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+name}:cancelLease', ) command.request_representation = Google::Apis::CloudtasksV2beta2::CancelLeaseRequest::Representation command.request_object = cancel_lease_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Task::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Task command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_queue(parent, queue_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Creates a queue. Queues created with this method allow tasks to live for a
maximum of 31 days. After a task is 31 days old, the task will be deleted
regardless of whether it was dispatched or not. WARNING: Using this method may
have unintended side effects if you are using an App Engine queue.yaml or
queue.xml file to manage your queues. Read Overview of Queue Management and
queue.yaml before using this
method.
311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 311 def create_project_location_queue(parent, queue_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+parent}/queues', ) command.request_representation = Google::Apis::CloudtasksV2beta2::Queue::Representation command.request_object = queue_object command.response_representation = Google::Apis::CloudtasksV2beta2::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Queue command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_task(parent, create_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Creates a task and adds it to a queue. Tasks cannot be updated after creation; there is no UpdateTask command. * For App Engine queues, the maximum task size is 100KB. * For pull queues, the maximum task size is 1MB.
885 886 887 888 889 890 891 892 893 894 895 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 885 def create_task(parent, create_task_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+parent}/tasks', ) command.request_representation = Google::Apis::CloudtasksV2beta2::CreateTaskRequest::Representation command.request_object = create_task_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Task::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Task command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_queue(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Empty
Deletes a queue. This command will delete the queue even if it has tasks in it.
Note: If you delete a queue, you may be prevented from creating a new queue
with the same name as the deleted queue for a tombstone window of up to 3 days.
During this window, the CreateQueue operation may appear to recreate the
queue, but this can be misleading. If you attempt to create a queue with the
same name as one that is in the tombstone window, run GetQueue to confirm that
the queue creation was successful. If GetQueue returns 200 response code, your
queue was successfully created with the name of the previously deleted queue.
Otherwise, your queue did not successfully recreate. WARNING: Using this
method may have unintended side effects if you are using an App Engine queue.
yaml or queue.xml file to manage your queues. Read Overview of Queue
Management and queue.yaml
before using this method.
356 357 358 359 360 361 362 363 364 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 356 def delete_project_location_queue(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta2/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta2::Empty::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_queue_task(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Empty
Deletes a task. A task can be deleted if it is scheduled or dispatched. A task cannot be deleted if it has completed successfully or permanently failed.
919 920 921 922 923 924 925 926 927 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 919 def delete_project_location_queue_task(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta2/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta2::Empty::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Location
Gets information about a location.
112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 112 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta2/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta2::Location::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::CmekConfig
Gets the CMEK config. Gets the Customer Managed Encryption Key configured with the Cloud Tasks lcoation. By default there is no kms_key configured.
144 145 146 147 148 149 150 151 152 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 144 def get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta2/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta2::CmekConfig::Representation command.response_class = Google::Apis::CloudtasksV2beta2::CmekConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
272 273 274 275 276 277 278 279 280 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 272 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta2/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta2::Operation::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_queue(name, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Gets a queue.
392 393 394 395 396 397 398 399 400 401 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 392 def get_project_location_queue(name, read_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta2/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta2::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Queue command.params['name'] = name unless name.nil? command.query['readMask'] = read_mask unless read_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_queue_task(name, response_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Gets a task.
957 958 959 960 961 962 963 964 965 966 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 957 def get_project_location_queue_task(name, response_view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta2/{+name}', ) command.response_representation = Google::Apis::CloudtasksV2beta2::Task::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Task command.params['name'] = name unless name.nil? command.query['responseView'] = response_view unless response_view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_queue_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Policy
Gets the access control policy for a Queue. Returns an empty policy if the
resource exists and does not have a policy set. Authorization requires the
following Google IAM permission on the
specified resource parent: * cloudtasks.queues.getIamPolicy
429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 429 def get_queue_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::CloudtasksV2beta2::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Policy::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lease_tasks(parent, lease_tasks_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::LeaseTasksResponse
Leases tasks from a pull queue for lease_duration. This method is invoked by the worker to obtain a lease. The worker must acknowledge the task via AcknowledgeTask after they have performed the work associated with the task. The payload is intended to store data that the worker needs to perform the work associated with the task. To return the payloads in the response, set response_view to FULL. A maximum of 10 qps of LeaseTasks requests are allowed per queue. RESOURCE_EXHAUSTED is returned when this limit is exceeded. RESOURCE_EXHAUSTED is also returned when max_tasks_dispatched_per_second is exceeded.
998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 998 def lease_tasks(parent, lease_tasks_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+parent}/tasks:lease', ) command.request_representation = Google::Apis::CloudtasksV2beta2::LeaseTasksRequest::Representation command.request_object = lease_tasks_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::LeaseTasksResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta2::LeaseTasksResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_queue_tasks(parent, page_size: nil, page_token: nil, response_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::ListTasksResponse
Lists the tasks in a queue. By default, only the BASIC view is retrieved due to performance considerations; response_view controls the subset of information which is returned. The tasks may be returned in any order. The ordering may change at any time.
1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 1051 def list_project_location_queue_tasks(parent, page_size: nil, page_token: nil, response_view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta2/{+parent}/tasks', ) command.response_representation = Google::Apis::CloudtasksV2beta2::ListTasksResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta2::ListTasksResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['responseView'] = response_view unless response_view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_queues(parent, filter: nil, page_size: nil, page_token: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::ListQueuesResponse
Lists queues. Queues are returned in lexicographical order.
485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 485 def list_project_location_queues(parent, filter: nil, page_size: nil, page_token: nil, read_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta2/{+parent}/queues', ) command.response_representation = Google::Apis::CloudtasksV2beta2::ListQueuesResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta2::ListQueuesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['readMask'] = read_mask unless read_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 196 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta2/{+name}/locations', ) command.response_representation = Google::Apis::CloudtasksV2beta2::ListLocationsResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta2::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_queue(name, queue_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Updates a queue. This method creates the queue if it does not exist and
updates the queue if it does exist. Queues created with this method allow
tasks to live for a maximum of 31 days. After a task is 31 days old, the task
will be deleted regardless of whether it was dispatched or not. WARNING: Using
this method may have unintended side effects if you are using an App Engine
queue.yaml or queue.xml file to manage your queues. Read Overview of Queue
Management and queue.yaml
before using this method.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 540 def patch_project_location_queue(name, queue_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2beta2/{+name}', ) command.request_representation = Google::Apis::CloudtasksV2beta2::Queue::Representation command.request_object = queue_object command.response_representation = Google::Apis::CloudtasksV2beta2::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Queue command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#pause_queue(name, pause_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Pauses the queue. If a queue is paused then the system will stop dispatching tasks until the queue is resumed via ResumeQueue. Tasks can still be added when the queue is paused. A queue is paused if its state is PAUSED.
577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 577 def pause_queue(name, pause_queue_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+name}:pause', ) command.request_representation = Google::Apis::CloudtasksV2beta2::PauseQueueRequest::Representation command.request_object = pause_queue_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Queue command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#purge_queue(name, purge_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Purges a queue by deleting all of its tasks. All tasks created before this method is called are permanently deleted. Purge operations can take up to one minute to take effect. Tasks might be dispatched before the purge takes effect. A purge is irreversible.
614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 614 def purge_queue(name, purge_queue_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+name}:purge', ) command.request_representation = Google::Apis::CloudtasksV2beta2::PurgeQueueRequest::Representation command.request_object = purge_queue_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Queue command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#renew_task_lease(name, renew_lease_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Renew the current lease of a pull task. The worker can use this method to extend the lease by a new duration, starting from now. The new task lease will be returned in the task's schedule_time.
1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 1088 def renew_task_lease(name, renew_lease_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+name}:renewLease', ) command.request_representation = Google::Apis::CloudtasksV2beta2::RenewLeaseRequest::Representation command.request_object = renew_lease_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Task::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Task command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resume_queue(name, resume_queue_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Queue
Resume a queue. This method resumes a queue after it has been PAUSED or DISABLED. The state of a queue is stored in the queue's state; after calling this method it will be set to RUNNING. WARNING: Resuming many high-QPS queues at the same time can lead to target overloading. If you are resuming high-QPS queues, follow the 500/50/5 pattern described in Managing Cloud Tasks Scaling Risks.
653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 653 def resume_queue(name, resume_queue_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+name}:resume', ) command.request_representation = Google::Apis::CloudtasksV2beta2::ResumeQueueRequest::Representation command.request_object = resume_queue_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Queue::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Queue command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_task(name, run_task_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Task
Forces a task to run now. When this method is called, Cloud Tasks will dispatch the task, even if the task is already running, the queue has reached its RateLimits or is PAUSED. This command is meant to be used for manual debugging. For example, RunTask can be used to retry a failed task after a fix has been made or to manually force a task to be dispatched now. The dispatched task is returned. That is, the task that is returned contains the status after the task is dispatched but before the task is received by its target. If Cloud Tasks receives a successful response from the task's target, then the task will be deleted; otherwise the task's schedule_time will be reset to the time that RunTask was called plus the retry delay specified in the queue's RetryConfig. RunTask returns NOT_FOUND when it is called on a task that has already succeeded or permanently failed. RunTask cannot be called on a pull task.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 1134 def run_task(name, run_task_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+name}:run', ) command.request_representation = Google::Apis::CloudtasksV2beta2::RunTaskRequest::Representation command.request_object = run_task_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Task::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Task command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_queue_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Policy
Sets the access control policy for a Queue. Replaces any existing policy. Note:
The Cloud Console does not check queue-level IAM permissions yet. Project-
level permissions are required to use the Cloud Console. Authorization
requires the following Google IAM permission
on the specified resource parent: * cloudtasks.queues.setIamPolicy
692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 692 def set_queue_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::CloudtasksV2beta2::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::CloudtasksV2beta2::Policy::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_queue_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::TestIamPermissionsResponse
Returns permissions that a caller has on a Queue. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may " fail open" without warning.
731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 731 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta2/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::CloudtasksV2beta2::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::CloudtasksV2beta2::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::CloudtasksV2beta2::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_api_queue(http_body_object = nil, app_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::Empty
Update queue list by uploading a queue.yaml file. The queue.yaml file is supplied in the request body as a YAML encoded string. This method was added to support gcloud clients versions before 322.0.0. New clients should use CreateQueue instead of this method.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 80 def update_api_queue(http_body_object = nil, app_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'api/queue/update', ) command.request_representation = Google::Apis::CloudtasksV2beta2::HttpBody::Representation command.request_object = http_body_object command.response_representation = Google::Apis::CloudtasksV2beta2::Empty::Representation command.response_class = Google::Apis::CloudtasksV2beta2::Empty command.query['appId'] = app_id unless app_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtasksV2beta2::CmekConfig
Creates or Updates a CMEK config. Updates the Customer Managed Encryption Key associated with the Cloud Tasks location (Creates if the key does not already exist). All new tasks created in the location will be encrypted at-rest with the KMS-key provided in the config.
238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/google/apis/cloudtasks_v2beta2/service.rb', line 238 def update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2beta2/{+name}', ) command.request_representation = Google::Apis::CloudtasksV2beta2::CmekConfig::Representation command.request_object = cmek_config_object command.response_representation = Google::Apis::CloudtasksV2beta2::CmekConfig::Representation command.response_class = Google::Apis::CloudtasksV2beta2::CmekConfig command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |