Class: Google::Apis::CloudtasksV2beta2::CreateTaskRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb

Overview

Request message for CreateTask.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateTaskRequest

Returns a new instance of CreateTaskRequest.



631
632
633
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The queue name. For example: projects/PROJECT_ID/locations/ LOCATION_ID/queues/QUEUE_ID The queue must already exist. Corresponds to the JSON property parent

Returns:

  • (String)


614
615
616
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 614

def parent
  @parent
end

#response_viewString

The response_view specifies which subset of the Task will be returned. By default response_view is BASIC; not all information is retrieved by default because some data, such as payloads, might be desirable to return only when needed because of its large size or because of the sensitivity of data that it contains. Authorization for FULL requires cloudtasks.tasks.fullView Google IAM permission on the Task resource. Corresponds to the JSON property responseView

Returns:

  • (String)


624
625
626
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 624

def response_view
  @response_view
end

#taskGoogle::Apis::CloudtasksV2beta2::Task

A unit of scheduled work. Corresponds to the JSON property task



629
630
631
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 629

def task
  @task
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



636
637
638
639
640
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 636

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @response_view = args[:response_view] if args.key?(:response_view)
  @task = args[:task] if args.key?(:task)
end