Class: Google::Apis::CloudtasksV2beta2::HttpRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudtasksV2beta2::HttpRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb
Overview
HTTP request. The task will be pushed to the worker as an HTTP request. An HTTP request embodies a url, an http method, headers, body and authorization for the http task.
Instance Attribute Summary collapse
-
#body ⇒ String
HTTP request body.
-
#headers ⇒ Hash<String,String>
HTTP request headers.
-
#http_method ⇒ String
The HTTP method to use for the request.
-
#oauth_token ⇒ Google::Apis::CloudtasksV2beta2::OAuthToken
Contains information needed for generating an OAuth token.
-
#oidc_token ⇒ Google::Apis::CloudtasksV2beta2::OidcToken
Contains information needed for generating an OpenID Connect token.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRequest
constructor
A new instance of HttpRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRequest
Returns a new instance of HttpRequest.
917 918 919 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 917 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body ⇒ String
HTTP request body. A request body is allowed only if the HTTP method is POST,
PUT, or PATCH. It is an error to set body on a task with an incompatible
HttpMethod.
Corresponds to the JSON property body
NOTE: Values are automatically base64 encoded/decoded in the client library.
864 865 866 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 864 def body @body end |
#headers ⇒ Hash<String,String>
HTTP request headers. This map contains the header field names and values.
Headers can be set when running the task is created or task is created. These
headers represent a subset of the headers that will accompany the task's HTTP
request. Some HTTP request headers will be ignored or replaced. A partial list
of headers that will be ignored or replaced is: * Any header that is prefixed
with "X-CloudTasks-" will be treated as service header. Service headers define
properties of the task and are predefined in CloudTask. * Host: This will be
computed by Cloud Tasks and derived from HttpRequest.url. * Content-Length:
This will be computed by Cloud Tasks. * User-Agent: This will be set to "
Google-Cloud-Tasks". * X-Google-*: Google use only. * X-AppEngine-*:
Google use only. Content-Type won't be set by Cloud Tasks. You can
explicitly set Content-Type to a media type when the task is created. For
example, Content-Type can be set to "application/octet-stream" or "
application/json". Headers which can have multiple values (according to
RFC2616) can be specified using comma-separated values. The size of the
headers must be less than 80KB.
Corresponds to the JSON property headers
884 885 886 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 884 def headers @headers end |
#http_method ⇒ String
The HTTP method to use for the request. The default is POST.
Corresponds to the JSON property httpMethod
889 890 891 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 889 def http_method @http_method end |
#oauth_token ⇒ Google::Apis::CloudtasksV2beta2::OAuthToken
Contains information needed for generating an OAuth token. This type of authorization should
generally only be used when calling Google APIs hosted on *.googleapis.com.
Corresponds to the JSON property oauthToken
896 897 898 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 896 def oauth_token @oauth_token end |
#oidc_token ⇒ Google::Apis::CloudtasksV2beta2::OidcToken
Contains information needed for generating an OpenID Connect token. This type of
authorization can be used for many scenarios, including calling Cloud Run, or
endpoints where you intend to validate the token yourself.
Corresponds to the JSON property oidcToken
904 905 906 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 904 def oidc_token @oidc_token end |
#url ⇒ String
Required. The full url path that the request will be sent to. This string must
begin with either "http://" or "https://". Some examples are: http://acme.com
and https://acme.com/sales:8080. Cloud Tasks will encode some characters
for safety and compatibility. The maximum allowed URL length is 2083
characters after encoding. The Location header response from a redirect
response [300 - 399] may be followed. The redirect is not counted as a
separate attempt.
Corresponds to the JSON property url
915 916 917 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 915 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
922 923 924 925 926 927 928 929 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 922 def update!(**args) @body = args[:body] if args.key?(:body) @headers = args[:headers] if args.key?(:headers) @http_method = args[:http_method] if args.key?(:http_method) @oauth_token = args[:oauth_token] if args.key?(:oauth_token) @oidc_token = args[:oidc_token] if args.key?(:oidc_token) @url = args[:url] if args.key?(:url) end |