Class: Google::Apis::CloudtasksV2beta2::HttpTarget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb

Overview

HTTP target. When specified as a Queue, all the tasks with [HttpRequest] will be overridden according to the target.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpTarget

Returns a new instance of HttpTarget.



989
990
991
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_overridesArray<Google::Apis::CloudtasksV2beta2::HeaderOverride>

HTTP target headers. This map contains the header field names and values. Headers will be set when running the task is created and/or task is created. These headers represent a subset of the headers that will accompany the task's HTTP request. Some HTTP request headers will be ignored or replaced. A partial list of headers that will be ignored or replaced is: * Any header that is prefixed with "X-CloudTasks-" will be treated as service header. Service headers define properties of the task and are predefined in CloudTask. * Host: This will be computed by Cloud Tasks and derived from HttpRequest.url. * Content-Length: This will be computed by Cloud Tasks. * User-Agent: This will be set to "Google-CloudTasks". * X-Google-*: Google use only. * X- AppEngine-*: Google use only. Content-Type won't be set by Cloud Tasks. You can explicitly set Content-Type to a media type when the task is created. For example, Content-Type can be set to "application/octet-stream" or " application/json". Headers which can have multiple values (according to RFC2616) can be specified using comma-separated values. The size of the headers must be less than 80KB. Queue-level headers to override headers of all the tasks in the queue. Do not put business sensitive or personally identifying data in the HTTP Header Override Configuration or other similar fields in accordance with Section 12 (Resource Fields) of the Service Specific Terms. Corresponds to the JSON property headerOverrides



959
960
961
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 959

def header_overrides
  @header_overrides
end

#http_methodString

The HTTP method to use for the request. When specified, it overrides HttpRequest for the task. Note that if the value is set to HttpMethod the HttpRequest of the task will be ignored at execution time. Corresponds to the JSON property httpMethod

Returns:

  • (String)


966
967
968
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 966

def http_method
  @http_method
end

#oauth_tokenGoogle::Apis::CloudtasksV2beta2::OAuthToken

Contains information needed for generating an OAuth token. This type of authorization should generally only be used when calling Google APIs hosted on *.googleapis.com. Corresponds to the JSON property oauthToken



973
974
975
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 973

def oauth_token
  @oauth_token
end

#oidc_tokenGoogle::Apis::CloudtasksV2beta2::OidcToken

Contains information needed for generating an OpenID Connect token. This type of authorization can be used for many scenarios, including calling Cloud Run, or endpoints where you intend to validate the token yourself. Corresponds to the JSON property oidcToken



981
982
983
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 981

def oidc_token
  @oidc_token
end

#uri_overrideGoogle::Apis::CloudtasksV2beta2::UriOverride

Uri Override. When specified, all the HTTP tasks inside the queue will be partially or fully overridden depending on the configured values. Corresponds to the JSON property uriOverride



987
988
989
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 987

def uri_override
  @uri_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



994
995
996
997
998
999
1000
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 994

def update!(**args)
  @header_overrides = args[:header_overrides] if args.key?(:header_overrides)
  @http_method = args[:http_method] if args.key?(:http_method)
  @oauth_token = args[:oauth_token] if args.key?(:oauth_token)
  @oidc_token = args[:oidc_token] if args.key?(:oidc_token)
  @uri_override = args[:uri_override] if args.key?(:uri_override)
end