Class: Google::Apis::CloudtasksV2beta2::BatchDeleteTasksRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudtasksV2beta2::BatchDeleteTasksRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb
Overview
Request message for deleting a batch of tasks using BatchDeleteTasks.
Instance Attribute Summary collapse
-
#names ⇒ Array<String>
Required.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchDeleteTasksRequest
constructor
A new instance of BatchDeleteTasksRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchDeleteTasksRequest
Returns a new instance of BatchDeleteTasksRequest.
378 379 380 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#names ⇒ Array<String>
Required. The names of the tasks to delete. A maximum of 1000 tasks can be
deleted in a batch. For example: Format: projects/PROJECT_ID/locations/
LOCATION_ID/queues/QUEUE_ID/tasks/TASK_ID
Corresponds to the JSON property names
369 370 371 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 369 def names @names end |
#request_id ⇒ String
Optional. This field will be used to identify the long running operation,
avoiding duplication when user retries. If not provided, then a UUID will be
generated at server side.
Corresponds to the JSON property requestId
376 377 378 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 376 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
383 384 385 386 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 383 def update!(**args) @names = args[:names] if args.key?(:names) @request_id = args[:request_id] if args.key?(:request_id) end |