Class: Google::Apis::CloudtasksV2beta2::OAuthToken
- Inherits:
-
Object
- Object
- Google::Apis::CloudtasksV2beta2::OAuthToken
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb
Overview
Contains information needed for generating an OAuth token. This type of authorization should generally only be used when calling Google APIs hosted on *.googleapis.com.
Instance Attribute Summary collapse
-
#scope ⇒ String
OAuth scope to be used for generating OAuth access token.
-
#service_account_email ⇒ String
Service account email to be used for generating OAuth token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OAuthToken
constructor
A new instance of OAuthToken.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OAuthToken
Returns a new instance of OAuthToken.
1234 1235 1236 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#scope ⇒ String
OAuth scope to be used for generating OAuth access token. If not specified, "
https://www.googleapis.com/auth/cloud-platform" will be used.
Corresponds to the JSON property scope
1224 1225 1226 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1224 def scope @scope end |
#service_account_email ⇒ String
Service account email to
be used for generating OAuth token. The service account must be within the
same project as the queue. The caller must have iam.serviceAccounts.actAs
permission for the service account.
Corresponds to the JSON property serviceAccountEmail
1232 1233 1234 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1232 def service_account_email @service_account_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1239 1240 1241 1242 |
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1239 def update!(**args) @scope = args[:scope] if args.key?(:scope) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) end |