Class: Google::Apis::CloudtasksV2beta2::QueueStats

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb

Overview

Statistics for a queue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueueStats

Returns a new instance of QueueStats.



1636
1637
1638
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#concurrent_dispatches_countFixnum

Output only. The number of requests that the queue has dispatched but has not received a reply for yet. Corresponds to the JSON property concurrentDispatchesCount

Returns:

  • (Fixnum)


1605
1606
1607
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1605

def concurrent_dispatches_count
  @concurrent_dispatches_count
end

#effective_execution_rateFloat

Output only. The current maximum number of tasks per second executed by the queue. The maximum value of this variable is controlled by the RateLimits of the Queue. However, this value could be less to avoid overloading the endpoints tasks in the queue are targeting. Corresponds to the JSON property effectiveExecutionRate

Returns:

  • (Float)


1613
1614
1615
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1613

def effective_execution_rate
  @effective_execution_rate
end

#executed_last_minute_countFixnum

Output only. The number of tasks that the queue has dispatched and received a reply for during the last minute. This variable counts both successful and non- successful executions. Corresponds to the JSON property executedLastMinuteCount

Returns:

  • (Fixnum)


1620
1621
1622
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1620

def executed_last_minute_count
  @executed_last_minute_count
end

#oldest_estimated_arrival_timeString

Output only. An estimation of the nearest time in the future where a task in the queue is scheduled to be executed. Corresponds to the JSON property oldestEstimatedArrivalTime

Returns:

  • (String)


1626
1627
1628
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1626

def oldest_estimated_arrival_time
  @oldest_estimated_arrival_time
end

#tasks_countFixnum

Output only. An estimation of the number of tasks in the queue, that is, the tasks in the queue that haven't been executed, the tasks in the queue which the queue has dispatched but has not yet received a reply for, and the failed tasks that the queue is retrying. Corresponds to the JSON property tasksCount

Returns:

  • (Fixnum)


1634
1635
1636
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1634

def tasks_count
  @tasks_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1641
1642
1643
1644
1645
1646
1647
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1641

def update!(**args)
  @concurrent_dispatches_count = args[:concurrent_dispatches_count] if args.key?(:concurrent_dispatches_count)
  @effective_execution_rate = args[:effective_execution_rate] if args.key?(:effective_execution_rate)
  @executed_last_minute_count = args[:executed_last_minute_count] if args.key?(:executed_last_minute_count)
  @oldest_estimated_arrival_time = args[:oldest_estimated_arrival_time] if args.key?(:oldest_estimated_arrival_time)
  @tasks_count = args[:tasks_count] if args.key?(:tasks_count)
end