Class: Google::Apis::CloudtasksV2beta2::RenewLeaseRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb

Overview

Request message for renewing a lease using RenewLease.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RenewLeaseRequest

Returns a new instance of RenewLeaseRequest.



1742
1743
1744
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lease_durationString

Required. The desired new lease duration, starting from now. The maximum lease duration is 1 week. lease_duration will be truncated to the nearest second. Corresponds to the JSON property leaseDuration

Returns:

  • (String)


1723
1724
1725
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1723

def lease_duration
  @lease_duration
end

#response_viewString

The response_view specifies which subset of the Task will be returned. By default response_view is BASIC; not all information is retrieved by default because some data, such as payloads, might be desirable to return only when needed because of its large size or because of the sensitivity of data that it contains. Authorization for FULL requires cloudtasks.tasks.fullView Google IAM permission on the Task resource. Corresponds to the JSON property responseView

Returns:

  • (String)


1733
1734
1735
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1733

def response_view
  @response_view
end

#schedule_timeString

Required. The task's current schedule time, available in the schedule_time returned by LeaseTasks response or RenewLease response. This restriction is to ensure that your worker currently holds the lease. Corresponds to the JSON property scheduleTime

Returns:

  • (String)


1740
1741
1742
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1740

def schedule_time
  @schedule_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1747
1748
1749
1750
1751
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 1747

def update!(**args)
  @lease_duration = args[:lease_duration] if args.key?(:lease_duration)
  @response_view = args[:response_view] if args.key?(:response_view)
  @schedule_time = args[:schedule_time] if args.key?(:schedule_time)
end