Class: Google::Apis::CloudtasksV2beta2::UriOverride

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtasks_v2beta2/classes.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb,
lib/google/apis/cloudtasks_v2beta2/representations.rb

Overview

Uri Override. When specified, all the HTTP tasks inside the queue will be partially or fully overridden depending on the configured values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UriOverride

Returns a new instance of UriOverride.



2198
2199
2200
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 2198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Host override. When specified, replaces the host part of the task URL. For example, if the task URL is "https://www.google.com," and host value is set to "example.net", the overridden URI will be changed to "https://example.net." Host value cannot be an empty string (INVALID_ARGUMENT). Corresponds to the JSON property host

Returns:

  • (String)


2165
2166
2167
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 2165

def host
  @host
end

#path_overrideGoogle::Apis::CloudtasksV2beta2::PathOverride

PathOverride. Path message defines path override for HTTP targets. Corresponds to the JSON property pathOverride



2170
2171
2172
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 2170

def path_override
  @path_override
end

#portFixnum

Port override. When specified, replaces the port part of the task URI. For instance, for a URI "https://www.example.com/example" and port=123, the overridden URI becomes "https://www.example.com:123/example". Note that the port value must be a positive integer. Setting the port to 0 (Zero) clears the URI port. Corresponds to the JSON property port

Returns:

  • (Fixnum)


2179
2180
2181
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 2179

def port
  @port
end

#query_overrideGoogle::Apis::CloudtasksV2beta2::QueryOverride

QueryOverride. Query message defines query override for HTTP targets. Corresponds to the JSON property queryOverride



2184
2185
2186
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 2184

def query_override
  @query_override
end

#schemeString

Scheme override. When specified, the task URI scheme is replaced by the provided value (HTTP or HTTPS). Corresponds to the JSON property scheme

Returns:

  • (String)


2190
2191
2192
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 2190

def scheme
  @scheme
end

#uri_override_enforce_modeString

URI Override Enforce Mode When specified, determines the Target UriOverride mode. If not specified, it defaults to ALWAYS. Corresponds to the JSON property uriOverrideEnforceMode

Returns:

  • (String)


2196
2197
2198
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 2196

def uri_override_enforce_mode
  @uri_override_enforce_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2203
2204
2205
2206
2207
2208
2209
2210
# File 'lib/google/apis/cloudtasks_v2beta2/classes.rb', line 2203

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @path_override = args[:path_override] if args.key?(:path_override)
  @port = args[:port] if args.key?(:port)
  @query_override = args[:query_override] if args.key?(:query_override)
  @scheme = args[:scheme] if args.key?(:scheme)
  @uri_override_enforce_mode = args[:uri_override_enforce_mode] if args.key?(:uri_override_enforce_mode)
end